@@ -2,15 +2,15 @@ use strict;
 use warnings;
 package Test::Magpie;
 {
-  $Test::Magpie::VERSION = '0.10';
+  $Test::Magpie::VERSION = '0.11';
 }
 # ABSTRACT: Mocking framework with method stubs and behaviour verification
 
 
 use aliased 'Test::Magpie::Inspect';
 use aliased 'Test::Magpie::Mock';
-use aliased 'Test::Magpie::Stubber';
 use aliased 'Test::Magpie::Verify';
+use aliased 'Test::Magpie::When';
 
 use Carp qw( croak );
 use Exporter qw( import );
@@ -20,14 +20,13 @@ use Test::Magpie::Types 'NumRange', Mock => { -as => 'MockType' };
 
 our @EXPORT = qw(
     mock
-    stub
+    when
     verify
 );
 our @EXPORT_OK = qw(
     at_least
     at_most
     inspect
-    when
 );
 
 
@@ -43,17 +42,13 @@ sub mock {
 }
 
 
-# old name for stub() deprecated because of potential clash
-# with given/when switch statements
-*when = \&stub;
-
-sub stub {
+sub when {
     my ($mock) = @_;
 
-    croak 'stub() must be given a mock object'
+    croak 'when() must be given a mock object'
         unless defined $mock && MockType->check($mock);
 
-    return Stubber->new(mock => $mock);
+    return When->new(mock => $mock);
 }
 
 
@@ -101,6 +96,7 @@ sub verify {
     return Verify->new(mock => $mock, %options);
 }
 
+
 sub inspect {
     my ($mock) = @_;
 
@@ -110,6 +106,7 @@ sub inspect {
     return Inspect->new(mock => $mock);
 }
 
+
 sub at_least {
     warnings::warnif('deprecated', 'at_least() is deprecated');
 
@@ -118,15 +115,16 @@ sub at_least {
         unless ! defined $n || looks_like_number $n;
 
     return sub {
-        my ($num_calls, $called, $test_name, $tb) = @_;
+        my ($invocations, $called, $test_name, $tb) = @_;
 
         $test_name = sprintf '%s was called at least %u time(s)', $called, $n
             unless defined $test_name;
 
-        $tb->cmp_ok($num_calls, '>=', $n, $test_name);
+        $tb->cmp_ok($invocations, '>=', $n, $test_name);
     }
 }
 
+
 sub at_most {
     warnings::warnif('deprecated', 'at_most() is deprecated');
 
@@ -135,12 +133,12 @@ sub at_most {
         unless ! defined $n || looks_like_number $n;
 
     return sub {
-        my ($num_calls, $called, $test_name, $tb) = @_;
+        my ($invocations, $called, $test_name, $tb) = @_;
 
         $test_name = sprintf '%s was called at most %u time(s)', $called, $n
             unless defined $test_name;
 
-        $tb->cmp_ok($num_calls, '<=', $n, $test_name);
+        $tb->cmp_ok($invocations, '<=', $n, $test_name);
     }
 }
 
@@ -150,21 +148,19 @@ __END__
 
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 Test::Magpie - Mocking framework with method stubs and behaviour verification
 
-=head1 VERSION
-
-version 0.10
-
 =head1 SYNOPSIS
 
     use Test::Magpie;
 
     # create the mock object and stub
     my $baker = mock;
-    stub($mock)->bake_loaf('white')->returns($bread);
+    when($mock)->bake_loaf('white')->then_return($bread);
 
     # execute the code under test
     my $bakery = Bakery->new( bakers => [ $baker ] );
@@ -231,13 +227,13 @@ blessed into. This value will be returned when C<ref()> is called on the object.
     $mock = mock($class);
     is( ref($mock), $class );
 
-=head2 stub
+=head2 when
 
-C<stub()> is used to tell the method stub to return some value(s) or to raise
+C<when()> is used to tell the method stub to return some value(s) or to raise
 an exception.
 
-    stub($mock)->method(@args)->returns(1, 2, 3);
-    stub($mock)->invalid(@args)->dies('exception');
+    when($mock)->method(@args)->then_return(1, 2, 3);
+    when($mock)->invalid(@args)->then_die('exception');
 
 =head2 verify
 
@@ -290,6 +286,32 @@ A C<$test_name> may also be supplied after the option.
 
     verify($mock, times => 3, $test_name)->method(@args)
 
+=head2 inspect
+
+Inspect method invocations on a mock object.
+
+    $invocation = inspect($mock)->method(@args);
+    is( $invocation->method_name, 'foo' );
+    is_deeply( [$invocation->arguments], [qw( bar baz )] );
+
+=head2 at_least (deprecated)
+
+Used with C<verify()> to verify that a method was invoked at least C<$n> times.
+
+    verify($mock, times => at_least($n))->method(@args);
+
+This function has been deprecated. Use the C<at_least> option for C<verify()>
+instead.
+
+=head2 at_most (deprecated)
+
+Used with C<verify()> to verify that a method was invoked at most C<$n> times.
+
+    verify($mock, times => at_most($n))->method(@args);
+
+This function has been deprecated. Use the C<at_most> option for C<verify()>
+instead.
+
 =head1 EXPORTS
 
 This module exports the following functions by default:
@@ -302,7 +324,7 @@ mock
 
 =item *
 
-stub
+when
 
 =item *
 
@@ -312,27 +334,6 @@ verify
 
 All other functions need to be imported explicitly.
 
-=for Pod::Coverage at_least at_most inspect when
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
-=head1 SUPPORT
-
-=head2 Bugs / Feature Requests
-
-Please report any bugs or feature requests by email to C<bug-test-magpie at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Test-Magpie>. You will be automatically notified of any
-progress on the request by the system.
-
-=head2 Source Code
-
-This is open source software. The code repository is available for
-public review and contribution under the terms of the license.
-
-L<http://github.com/ocharles/Test-Magpie>
-
-  git clone http://github.com/ocharles/Test-Magpie.git
-
 =head1 AUTHORS
 
 =over 4
